@@ -22,7 +22,7 @@ use Apache::Session::Lock::File;
 use File::Path;
 use Params::Validate qw( :all );
 
-our $VERSION = 0.03;
+our $VERSION = 0.05;
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~[  OBJECT METHODS  ]~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
 
@@ -89,26 +89,31 @@ sub create {
 
     untie %session;
 
+    $c->plugin('Cookie')->set( $c, {
+        name    => $name,
+        value   => $id,
+        expires => $c->config->{session_expires} || '24h',
+      });
+
     return $id;
 }
 
 #----------------------------------------------------------------------------+
-# get( \%controller, $name, $id )
+# get( \%controller, $name )
 #
 # Return session data as a hash reference.
 
 sub get {
-    my ( $self, $c, $name, $id )
+    my ( $self, $c, $name )
       = validate_pos( @_,
           { type => OBJECT  },
           { type => HASHREF },
-          { type => SCALAR  },
-          { type => SCALAR, optional => 1 }
+          { type => SCALAR  }
           );
 
     my $doc_root = $c->config->{apache_doc_root};
 
-    my $cookie = $c->plugin('Cookie')->get($name) || $id;
+    my $cookie = $c->plugin('Cookie')->get($name);
 
     my $session_id = ($cookie) ? $cookie : "null";
 
@@ -285,6 +290,7 @@ Unless it already exists, add the following to your projects I<webapp.conf>
 
   [session]
   storage_type = file
+  expires = 1h
 
 =head1 OBJECT METHODS
 
